from typing import Any, Callable
from grpc_interceptor import ClientCallDetails, ClientInterceptor

import grpc 

class MetadataClientInterceptor(ClientInterceptor):

    def __init__(self, client_id, api_key) -> None:
        super().__init__()
        self.client_id = client_id
        self.api_key = api_key

    def intercept(
        self,
        method: Callable,
        request_or_iterator: Any,
        call_details: grpc.ClientCallDetails,
    ):
        """Override this method to implement a custom interceptor.

        This method is called for all unary and streaming RPCs. The interceptor
        implementation should call `method` using a `grpc.ClientCallDetails` and the
        `request_or_iterator` object as parameters. The `request_or_iterator`
        parameter may be type checked to determine if this is a singluar request
        for unary RPCs or an iterator for client-streaming or client-server streaming
        RPCs.

        Args:
            method: A function that proceeds with the invocation by executing the next
                interceptor in the chain or invoking the actual RPC on the underlying
                channel.
            request_or_iterator: RPC request message or iterator of request messages
                for streaming requests.
            call_details: Describes an RPC to be invoked.

        Returns:
            The type of the return should match the type of the return value received
            by calling `method`. This is an object that is both a
            `Call <https://grpc.github.io/grpc/python/grpc.html#grpc.Call>`_ for the
            RPC and a `Future <https://grpc.github.io/grpc/python/grpc.html#grpc.Future>`_.

            The actual result from the RPC can be got by calling `.result()` on the
            value returned from `method`.
        """
        new_details = ClientCallDetails(
            call_details.method,
            600,
            [("client_id", self.client_id), ("api_key", self.api_key), ],
            call_details.credentials,
            call_details.wait_for_ready,
            call_details.compression,
        )

        return method(request_or_iterator, new_details)



from validate.v1 import validate_pb2 as _validate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Chunk(_message.Message):
    __slots__ = ["chunk"]
    CHUNK_FIELD_NUMBER: _ClassVar[int]
    chunk: bytes
    def __init__(self, chunk: _Optional[bytes] = ...) -> None: ...

class CreateInventoryObjectRequest(_message.Message):
    __slots__ = ["column", "datastore_id", "db", "object_type", "schema", "sub_column", "table"]
    class Column(_message.Message):
        __slots__ = ["data_type", "name", "path"]
        DATA_TYPE_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        PATH_FIELD_NUMBER: _ClassVar[int]
        data_type: str
        name: str
        path: str
        def __init__(self, path: _Optional[str] = ..., name: _Optional[str] = ..., data_type: _Optional[str] = ...) -> None: ...
    class Db(_message.Message):
        __slots__ = ["name", "path"]
        NAME_FIELD_NUMBER: _ClassVar[int]
        PATH_FIELD_NUMBER: _ClassVar[int]
        name: str
        path: str
        def __init__(self, path: _Optional[str] = ..., name: _Optional[str] = ...) -> None: ...
    class Schema(_message.Message):
        __slots__ = ["name", "path"]
        NAME_FIELD_NUMBER: _ClassVar[int]
        PATH_FIELD_NUMBER: _ClassVar[int]
        name: str
        path: str
        def __init__(self, path: _Optional[str] = ..., name: _Optional[str] = ...) -> None: ...
    class SubColumn(_message.Message):
        __slots__ = ["name", "path", "sub_type"]
        NAME_FIELD_NUMBER: _ClassVar[int]
        PATH_FIELD_NUMBER: _ClassVar[int]
        SUB_TYPE_FIELD_NUMBER: _ClassVar[int]
        name: str
        path: str
        sub_type: str
        def __init__(self, path: _Optional[str] = ..., name: _Optional[str] = ..., sub_type: _Optional[str] = ...) -> None: ...
    class Table(_message.Message):
        __slots__ = ["name", "path"]
        NAME_FIELD_NUMBER: _ClassVar[int]
        PATH_FIELD_NUMBER: _ClassVar[int]
        name: str
        path: str
        def __init__(self, path: _Optional[str] = ..., name: _Optional[str] = ...) -> None: ...
    COLUMN_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    DB_FIELD_NUMBER: _ClassVar[int]
    OBJECT_TYPE_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    SUB_COLUMN_FIELD_NUMBER: _ClassVar[int]
    TABLE_FIELD_NUMBER: _ClassVar[int]
    column: CreateInventoryObjectRequest.Column
    datastore_id: str
    db: CreateInventoryObjectRequest.Db
    object_type: str
    schema: CreateInventoryObjectRequest.Schema
    sub_column: CreateInventoryObjectRequest.SubColumn
    table: CreateInventoryObjectRequest.Table
    def __init__(self, datastore_id: _Optional[str] = ..., object_type: _Optional[str] = ..., db: _Optional[_Union[CreateInventoryObjectRequest.Db, _Mapping]] = ..., schema: _Optional[_Union[CreateInventoryObjectRequest.Schema, _Mapping]] = ..., table: _Optional[_Union[CreateInventoryObjectRequest.Table, _Mapping]] = ..., column: _Optional[_Union[CreateInventoryObjectRequest.Column, _Mapping]] = ..., sub_column: _Optional[_Union[CreateInventoryObjectRequest.SubColumn, _Mapping]] = ...) -> None: ...

class CreateInventoryObjectResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class CreateInventoryTagRequest(_message.Message):
    __slots__ = ["name"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class CreateInventoryTagResponse(_message.Message):
    __slots__ = ["tag"]
    TAG_FIELD_NUMBER: _ClassVar[int]
    tag: Tag
    def __init__(self, tag: _Optional[_Union[Tag, _Mapping]] = ...) -> None: ...

class DeleteInventoryObjectRequest(_message.Message):
    __slots__ = ["datastore_id", "path"]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    datastore_id: str
    path: str
    def __init__(self, datastore_id: _Optional[str] = ..., path: _Optional[str] = ...) -> None: ...

class DeleteInventoryObjectResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DeleteInventoryTagRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeleteInventoryTagResponse(_message.Message):
    __slots__ = ["tags"]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    tags: _containers.RepeatedCompositeFieldContainer[Tag]
    def __init__(self, tags: _Optional[_Iterable[_Union[Tag, _Mapping]]] = ...) -> None: ...

class Empty(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetInventoryFlatRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetInventoryFlatResponse(_message.Message):
    __slots__ = ["inventory"]
    class Column(_message.Message):
        __slots__ = ["alias", "created_at", "data_label", "data_type", "data_type_oid", "datastore_id", "datastore_name", "name", "path", "table_attribute_number", "table_path", "table_physical_id", "tags", "updated_at", "validated"]
        ALIAS_FIELD_NUMBER: _ClassVar[int]
        CREATED_AT_FIELD_NUMBER: _ClassVar[int]
        DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
        DATASTORE_NAME_FIELD_NUMBER: _ClassVar[int]
        DATA_LABEL_FIELD_NUMBER: _ClassVar[int]
        DATA_TYPE_FIELD_NUMBER: _ClassVar[int]
        DATA_TYPE_OID_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        PATH_FIELD_NUMBER: _ClassVar[int]
        TABLE_ATTRIBUTE_NUMBER_FIELD_NUMBER: _ClassVar[int]
        TABLE_PATH_FIELD_NUMBER: _ClassVar[int]
        TABLE_PHYSICAL_ID_FIELD_NUMBER: _ClassVar[int]
        TAGS_FIELD_NUMBER: _ClassVar[int]
        UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
        VALIDATED_FIELD_NUMBER: _ClassVar[int]
        alias: str
        created_at: int
        data_label: str
        data_type: str
        data_type_oid: int
        datastore_id: str
        datastore_name: str
        name: str
        path: str
        table_attribute_number: int
        table_path: str
        table_physical_id: str
        tags: _containers.RepeatedScalarFieldContainer[str]
        updated_at: int
        validated: bool
        def __init__(self, created_at: _Optional[int] = ..., updated_at: _Optional[int] = ..., datastore_id: _Optional[str] = ..., datastore_name: _Optional[str] = ..., path: _Optional[str] = ..., table_physical_id: _Optional[str] = ..., table_attribute_number: _Optional[int] = ..., name: _Optional[str] = ..., alias: _Optional[str] = ..., table_path: _Optional[str] = ..., data_label: _Optional[str] = ..., data_type: _Optional[str] = ..., data_type_oid: _Optional[int] = ..., validated: bool = ..., tags: _Optional[_Iterable[str]] = ...) -> None: ...
    INVENTORY_FIELD_NUMBER: _ClassVar[int]
    inventory: _containers.RepeatedCompositeFieldContainer[GetInventoryFlatResponse.Column]
    def __init__(self, inventory: _Optional[_Iterable[_Union[GetInventoryFlatResponse.Column, _Mapping]]] = ...) -> None: ...

class GetInventoryHierarchicalRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetInventoryHierarchicalResponse(_message.Message):
    __slots__ = ["inventory"]
    class Column(_message.Message):
        __slots__ = ["hstores", "name", "path", "table_path"]
        HSTORES_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        PATH_FIELD_NUMBER: _ClassVar[int]
        TABLE_PATH_FIELD_NUMBER: _ClassVar[int]
        hstores: _containers.RepeatedCompositeFieldContainer[GetInventoryHierarchicalResponse.SubColumn]
        name: str
        path: str
        table_path: str
        def __init__(self, path: _Optional[str] = ..., name: _Optional[str] = ..., table_path: _Optional[str] = ..., hstores: _Optional[_Iterable[_Union[GetInventoryHierarchicalResponse.SubColumn, _Mapping]]] = ...) -> None: ...
    class Datastore(_message.Message):
        __slots__ = ["dbs", "id", "name"]
        DBS_FIELD_NUMBER: _ClassVar[int]
        ID_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        dbs: _containers.RepeatedCompositeFieldContainer[GetInventoryHierarchicalResponse.Db]
        id: str
        name: str
        def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., dbs: _Optional[_Iterable[_Union[GetInventoryHierarchicalResponse.Db, _Mapping]]] = ...) -> None: ...
    class Db(_message.Message):
        __slots__ = ["datastore_id", "name", "path", "schemas", "tables"]
        DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        PATH_FIELD_NUMBER: _ClassVar[int]
        SCHEMAS_FIELD_NUMBER: _ClassVar[int]
        TABLES_FIELD_NUMBER: _ClassVar[int]
        datastore_id: str
        name: str
        path: str
        schemas: _containers.RepeatedCompositeFieldContainer[GetInventoryHierarchicalResponse.Schema]
        tables: _containers.RepeatedCompositeFieldContainer[GetInventoryHierarchicalResponse.Table]
        def __init__(self, path: _Optional[str] = ..., name: _Optional[str] = ..., datastore_id: _Optional[str] = ..., schemas: _Optional[_Iterable[_Union[GetInventoryHierarchicalResponse.Schema, _Mapping]]] = ..., tables: _Optional[_Iterable[_Union[GetInventoryHierarchicalResponse.Table, _Mapping]]] = ...) -> None: ...
    class Schema(_message.Message):
        __slots__ = ["db_path", "name", "path", "tables"]
        DB_PATH_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        PATH_FIELD_NUMBER: _ClassVar[int]
        TABLES_FIELD_NUMBER: _ClassVar[int]
        db_path: str
        name: str
        path: str
        tables: _containers.RepeatedCompositeFieldContainer[GetInventoryHierarchicalResponse.Table]
        def __init__(self, path: _Optional[str] = ..., name: _Optional[str] = ..., db_path: _Optional[str] = ..., tables: _Optional[_Iterable[_Union[GetInventoryHierarchicalResponse.Table, _Mapping]]] = ...) -> None: ...
    class SubColumn(_message.Message):
        __slots__ = ["column_path", "name", "path"]
        COLUMN_PATH_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        PATH_FIELD_NUMBER: _ClassVar[int]
        column_path: str
        name: str
        path: str
        def __init__(self, path: _Optional[str] = ..., name: _Optional[str] = ..., column_path: _Optional[str] = ...) -> None: ...
    class Table(_message.Message):
        __slots__ = ["columns", "db_path", "name", "path", "schema_path"]
        COLUMNS_FIELD_NUMBER: _ClassVar[int]
        DB_PATH_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        PATH_FIELD_NUMBER: _ClassVar[int]
        SCHEMA_PATH_FIELD_NUMBER: _ClassVar[int]
        columns: _containers.RepeatedCompositeFieldContainer[GetInventoryHierarchicalResponse.Column]
        db_path: str
        name: str
        path: str
        schema_path: str
        def __init__(self, path: _Optional[str] = ..., name: _Optional[str] = ..., db_path: _Optional[str] = ..., schema_path: _Optional[str] = ..., columns: _Optional[_Iterable[_Union[GetInventoryHierarchicalResponse.Column, _Mapping]]] = ...) -> None: ...
    INVENTORY_FIELD_NUMBER: _ClassVar[int]
    inventory: _containers.RepeatedCompositeFieldContainer[GetInventoryHierarchicalResponse.Datastore]
    def __init__(self, inventory: _Optional[_Iterable[_Union[GetInventoryHierarchicalResponse.Datastore, _Mapping]]] = ...) -> None: ...

class GetInventoryTagsRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetInventoryTagsResponse(_message.Message):
    __slots__ = ["tags"]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    tags: _containers.RepeatedCompositeFieldContainer[Tag]
    def __init__(self, tags: _Optional[_Iterable[_Union[Tag, _Mapping]]] = ...) -> None: ...

class Tag(_message.Message):
    __slots__ = ["created_at", "id", "name"]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    created_at: int
    id: str
    name: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., created_at: _Optional[int] = ...) -> None: ...

class UpdateColumnDataLabelRequest(_message.Message):
    __slots__ = ["data_label", "datastore_id", "path"]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    DATA_LABEL_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    data_label: str
    datastore_id: str
    path: str
    def __init__(self, datastore_id: _Optional[str] = ..., path: _Optional[str] = ..., data_label: _Optional[str] = ...) -> None: ...

class UpdateColumnDataLabelResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateColumnLockStatusRequest(_message.Message):
    __slots__ = ["datastore_id", "path", "validated"]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    VALIDATED_FIELD_NUMBER: _ClassVar[int]
    datastore_id: str
    path: str
    validated: bool
    def __init__(self, datastore_id: _Optional[str] = ..., path: _Optional[str] = ..., validated: bool = ...) -> None: ...

class UpdateColumnLockStatusResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateInventoryObjectTagsRequest(_message.Message):
    __slots__ = ["datastore_id", "path", "tags"]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    datastore_id: str
    path: str
    tags: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, datastore_id: _Optional[str] = ..., path: _Optional[str] = ..., tags: _Optional[_Iterable[str]] = ...) -> None: ...

class UpdateInventoryObjectTagsResponse(_message.Message):
    __slots__ = ["object"]
    class InventoryObject(_message.Message):
        __slots__ = ["created_at", "data_label", "data_store_name", "data_type", "datastore_id", "db_path", "name", "path", "schema_path", "table_attribute_number", "table_path", "tags", "type", "updated_at", "validated"]
        CREATED_AT_FIELD_NUMBER: _ClassVar[int]
        DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
        DATA_LABEL_FIELD_NUMBER: _ClassVar[int]
        DATA_STORE_NAME_FIELD_NUMBER: _ClassVar[int]
        DATA_TYPE_FIELD_NUMBER: _ClassVar[int]
        DB_PATH_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        PATH_FIELD_NUMBER: _ClassVar[int]
        SCHEMA_PATH_FIELD_NUMBER: _ClassVar[int]
        TABLE_ATTRIBUTE_NUMBER_FIELD_NUMBER: _ClassVar[int]
        TABLE_PATH_FIELD_NUMBER: _ClassVar[int]
        TAGS_FIELD_NUMBER: _ClassVar[int]
        TYPE_FIELD_NUMBER: _ClassVar[int]
        UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
        VALIDATED_FIELD_NUMBER: _ClassVar[int]
        created_at: int
        data_label: str
        data_store_name: str
        data_type: str
        datastore_id: str
        db_path: str
        name: str
        path: str
        schema_path: str
        table_attribute_number: int
        table_path: str
        tags: _containers.RepeatedScalarFieldContainer[str]
        type: str
        updated_at: int
        validated: bool
        def __init__(self, datastore_id: _Optional[str] = ..., type: _Optional[str] = ..., path: _Optional[str] = ..., db_path: _Optional[str] = ..., table_path: _Optional[str] = ..., schema_path: _Optional[str] = ..., table_attribute_number: _Optional[int] = ..., data_type: _Optional[str] = ..., data_label: _Optional[str] = ..., updated_at: _Optional[int] = ..., created_at: _Optional[int] = ..., data_store_name: _Optional[str] = ..., name: _Optional[str] = ..., validated: bool = ..., tags: _Optional[_Iterable[str]] = ...) -> None: ...
    OBJECT_FIELD_NUMBER: _ClassVar[int]
    object: UpdateInventoryObjectTagsResponse.InventoryObject
    def __init__(self, object: _Optional[_Union[UpdateInventoryObjectTagsResponse.InventoryObject, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aa_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


# from validate.v1 import validate_pb2 as validate_dot_v1_dot_validate__pb2
from .validate.v1 import validate_pb2 as validate_dot_v1_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x61\x61_service.proto\x12\raa_service.v1\x1a\x1avalidate/v1/validate.proto\"\x07\n\x05\x45mpty\"\x16\n\x05\x43hunk\x12\r\n\x05\x63hunk\x18\x01 \x01(\x0c\"!\n\x1fGetInventoryHierarchicalRequest\"\xf9\x06\n GetInventoryHierarchicalResponse\x12L\n\tinventory\x18\x01 \x03(\x0b\x32\x39.aa_service.v1.GetInventoryHierarchicalResponse.Datastore\x1a\x66\n\tDatastore\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12?\n\x03\x64\x62s\x18\x03 \x03(\x0b\x32\x32.aa_service.v1.GetInventoryHierarchicalResponse.Db\x1a\xc6\x01\n\x02\x44\x62\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x14\n\x0c\x64\x61tastore_id\x18\x03 \x01(\t\x12G\n\x07schemas\x18\x04 \x03(\x0b\x32\x36.aa_service.v1.GetInventoryHierarchicalResponse.Schema\x12\x45\n\x06tables\x18\x05 \x03(\x0b\x32\x35.aa_service.v1.GetInventoryHierarchicalResponse.Table\x1a|\n\x06Schema\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x64\x62_path\x18\x03 \x01(\t\x12\x45\n\x06tables\x18\x04 \x03(\x0b\x32\x35.aa_service.v1.GetInventoryHierarchicalResponse.Table\x1a\x92\x01\n\x05Table\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x64\x62_path\x18\x03 \x01(\t\x12\x13\n\x0bschema_path\x18\x04 \x01(\t\x12G\n\x07\x63olumns\x18\x05 \x03(\x0b\x32\x36.aa_service.v1.GetInventoryHierarchicalResponse.Column\x1a\x84\x01\n\x06\x43olumn\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\ntable_path\x18\x03 \x01(\t\x12J\n\x07hstores\x18\x04 \x03(\x0b\x32\x39.aa_service.v1.GetInventoryHierarchicalResponse.SubColumn\x1a<\n\tSubColumn\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x63olumn_path\x18\x03 \x01(\t\"\x19\n\x17GetInventoryFlatRequest\"\x97\x03\n\x18GetInventoryFlatResponse\x12\x41\n\tinventory\x18\x01 \x03(\x0b\x32..aa_service.v1.GetInventoryFlatResponse.Column\x1a\xb7\x02\n\x06\x43olumn\x12\x12\n\ncreated_at\x18\x01 \x01(\x03\x12\x12\n\nupdated_at\x18\x02 \x01(\x03\x12\x14\n\x0c\x64\x61tastore_id\x18\x03 \x01(\t\x12\x16\n\x0e\x64\x61tastore_name\x18\x04 \x01(\t\x12\x0c\n\x04path\x18\x05 \x01(\t\x12\x19\n\x11table_physical_id\x18\x06 \x01(\t\x12\x1e\n\x16table_attribute_number\x18\x07 \x01(\x04\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\r\n\x05\x61lias\x18\t \x01(\t\x12\x12\n\ntable_path\x18\n \x01(\t\x12\x12\n\ndata_label\x18\x0b \x01(\t\x12\x11\n\tdata_type\x18\x0c \x01(\t\x12\x15\n\rdata_type_oid\x18\r \x01(\r\x12\x11\n\tvalidated\x18\x0e \x01(\x08\x12\x0c\n\x04tags\x18\x0f \x03(\t\"h\n\x1dUpdateColumnLockStatusRequest\x12\x1d\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x15\n\x04path\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x11\n\tvalidated\x18\x03 \x01(\x08\" \n\x1eUpdateColumnLockStatusResponse\"h\n\x1cUpdateColumnDataLabelRequest\x12\x1d\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x15\n\x04path\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x12\n\ndata_label\x18\x03 \x01(\t\"\x1f\n\x1dUpdateColumnDataLabelResponse\"\xaa\x06\n\x1c\x43reateInventoryObjectRequest\x12\x1d\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x41\n\x0bobject_type\x18\x02 \x01(\tB,\xfa\x42)r\'R\x02\x64\x62R\x06schemaR\x05tableR\x06\x63olumnR\nsub-column\x12:\n\x02\x64\x62\x18\x03 \x01(\x0b\x32..aa_service.v1.CreateInventoryObjectRequest.Db\x12\x42\n\x06schema\x18\x04 \x01(\x0b\x32\x32.aa_service.v1.CreateInventoryObjectRequest.Schema\x12@\n\x05table\x18\x05 \x01(\x0b\x32\x31.aa_service.v1.CreateInventoryObjectRequest.Table\x12\x42\n\x06\x63olumn\x18\x06 \x01(\x0b\x32\x32.aa_service.v1.CreateInventoryObjectRequest.Column\x12I\n\nsub_column\x18\x07 \x01(\x0b\x32\x35.aa_service.v1.CreateInventoryObjectRequest.SubColumn\x1a\x32\n\x02\x44\x62\x12\x15\n\x04path\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x15\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x1a\x36\n\x06Schema\x12\x15\n\x04path\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x15\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x1a\x35\n\x05Table\x12\x15\n\x04path\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x15\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x1aR\n\x06\x43olumn\x12\x15\n\x04path\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x15\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1a\n\tdata_type\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x1a`\n\tSubColumn\x12\x15\n\x04path\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x15\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12%\n\x08sub_type\x18\x03 \x01(\tB\x13\xfa\x42\x10r\x0eR\x06hstoreR\x04json\"\x1f\n\x1d\x43reateInventoryObjectResponse\"T\n\x1c\x44\x65leteInventoryObjectRequest\x12\x1d\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x15\n\x04path\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\x1f\n\x1d\x44\x65leteInventoryObjectResponse\"<\n\x03Tag\x12\n\n\x02id\x18\x01 \x01(\t\x12\x15\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x12\n\ncreated_at\x18\x03 \x01(\x03\"2\n\x19\x43reateInventoryTagRequest\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"=\n\x1a\x43reateInventoryTagResponse\x12\x1f\n\x03tag\x18\x01 \x01(\x0b\x32\x12.aa_service.v1.Tag\"\x19\n\x17GetInventoryTagsRequest\"<\n\x18GetInventoryTagsResponse\x12 \n\x04tags\x18\x01 \x03(\x0b\x32\x12.aa_service.v1.Tag\"f\n UpdateInventoryObjectTagsRequest\x12\x1d\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x15\n\x04path\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x0c\n\x04tags\x18\x03 \x03(\t\"\xac\x03\n!UpdateInventoryObjectTagsResponse\x12P\n\x06object\x18\x01 \x01(\x0b\x32@.aa_service.v1.UpdateInventoryObjectTagsResponse.InventoryObject\x1a\xb4\x02\n\x0fInventoryObject\x12\x14\n\x0c\x64\x61tastore_id\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x0f\n\x07\x64\x62_path\x18\x04 \x01(\t\x12\x12\n\ntable_path\x18\x05 \x01(\t\x12\x13\n\x0bschema_path\x18\x06 \x01(\t\x12\x1e\n\x16table_attribute_number\x18\x07 \x01(\x04\x12\x11\n\tdata_type\x18\x08 \x01(\t\x12\x12\n\ndata_label\x18\t \x01(\t\x12\x12\n\nupdated_at\x18\n \x01(\x03\x12\x12\n\ncreated_at\x18\x0b \x01(\x03\x12\x17\n\x0f\x64\x61ta_store_name\x18\x0c \x01(\t\x12\x0c\n\x04name\x18\r \x01(\t\x12\x11\n\tvalidated\x18\x0e \x01(\x08\x12\x0c\n\x04tags\x18\x0f \x03(\t\"0\n\x19\x44\x65leteInventoryTagRequest\x12\x13\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\">\n\x1a\x44\x65leteInventoryTagResponse\x12 \n\x04tags\x18\x01 \x03(\x0b\x32\x12.aa_service.v1.Tag2\x96\t\n\x0f\x41\x64minApiService\x12}\n\x18GetInventoryHierarchical\x12..aa_service.v1.GetInventoryHierarchicalRequest\x1a/.aa_service.v1.GetInventoryHierarchicalResponse\"\x00\x12\x65\n\x10GetInventoryFlat\x12&.aa_service.v1.GetInventoryFlatRequest\x1a\'.aa_service.v1.GetInventoryFlatResponse\"\x00\x12w\n\x16UpdateColumnLockStatus\x12,.aa_service.v1.UpdateColumnLockStatusRequest\x1a-.aa_service.v1.UpdateColumnLockStatusResponse\"\x00\x12t\n\x15UpdateColumnDataLabel\x12+.aa_service.v1.UpdateColumnDataLabelRequest\x1a,.aa_service.v1.UpdateColumnDataLabelResponse\"\x00\x12t\n\x15\x43reateInventoryObject\x12+.aa_service.v1.CreateInventoryObjectRequest\x1a,.aa_service.v1.CreateInventoryObjectResponse\"\x00\x12t\n\x15\x44\x65leteInventoryObject\x12+.aa_service.v1.DeleteInventoryObjectRequest\x1a,.aa_service.v1.DeleteInventoryObjectResponse\"\x00\x12k\n\x12\x43reateInventoryTag\x12(.aa_service.v1.CreateInventoryTagRequest\x1a).aa_service.v1.CreateInventoryTagResponse\"\x00\x12\x65\n\x10GetInventoryTags\x12&.aa_service.v1.GetInventoryTagsRequest\x1a\'.aa_service.v1.GetInventoryTagsResponse\"\x00\x12\x80\x01\n\x19UpdateInventoryObjectTags\x12/.aa_service.v1.UpdateInventoryObjectTagsRequest\x1a\x30.aa_service.v1.UpdateInventoryObjectTagsResponse\"\x00\x12k\n\x12\x44\x65leteInventoryTag\x12(.aa_service.v1.DeleteInventoryTagRequest\x1a).aa_service.v1.DeleteInventoryTagResponse\"\x00\x42TZRgithub.com/formalco/control-plane/backend/admin-api/gen/aa_service/v1;aa_servicev1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aa_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZRgithub.com/formalco/control-plane/backend/admin-api/gen/aa_service/v1;aa_servicev1'
  _UPDATECOLUMNLOCKSTATUSREQUEST.fields_by_name['datastore_id']._options = None
  _UPDATECOLUMNLOCKSTATUSREQUEST.fields_by_name['datastore_id']._serialized_options = b'\372B\004r\002\020\001'
  _UPDATECOLUMNLOCKSTATUSREQUEST.fields_by_name['path']._options = None
  _UPDATECOLUMNLOCKSTATUSREQUEST.fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _UPDATECOLUMNDATALABELREQUEST.fields_by_name['datastore_id']._options = None
  _UPDATECOLUMNDATALABELREQUEST.fields_by_name['datastore_id']._serialized_options = b'\372B\004r\002\020\001'
  _UPDATECOLUMNDATALABELREQUEST.fields_by_name['path']._options = None
  _UPDATECOLUMNDATALABELREQUEST.fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEINVENTORYOBJECTREQUEST_DB.fields_by_name['path']._options = None
  _CREATEINVENTORYOBJECTREQUEST_DB.fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEINVENTORYOBJECTREQUEST_DB.fields_by_name['name']._options = None
  _CREATEINVENTORYOBJECTREQUEST_DB.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEINVENTORYOBJECTREQUEST_SCHEMA.fields_by_name['path']._options = None
  _CREATEINVENTORYOBJECTREQUEST_SCHEMA.fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEINVENTORYOBJECTREQUEST_SCHEMA.fields_by_name['name']._options = None
  _CREATEINVENTORYOBJECTREQUEST_SCHEMA.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEINVENTORYOBJECTREQUEST_TABLE.fields_by_name['path']._options = None
  _CREATEINVENTORYOBJECTREQUEST_TABLE.fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEINVENTORYOBJECTREQUEST_TABLE.fields_by_name['name']._options = None
  _CREATEINVENTORYOBJECTREQUEST_TABLE.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEINVENTORYOBJECTREQUEST_COLUMN.fields_by_name['path']._options = None
  _CREATEINVENTORYOBJECTREQUEST_COLUMN.fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEINVENTORYOBJECTREQUEST_COLUMN.fields_by_name['name']._options = None
  _CREATEINVENTORYOBJECTREQUEST_COLUMN.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEINVENTORYOBJECTREQUEST_COLUMN.fields_by_name['data_type']._options = None
  _CREATEINVENTORYOBJECTREQUEST_COLUMN.fields_by_name['data_type']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEINVENTORYOBJECTREQUEST_SUBCOLUMN.fields_by_name['path']._options = None
  _CREATEINVENTORYOBJECTREQUEST_SUBCOLUMN.fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEINVENTORYOBJECTREQUEST_SUBCOLUMN.fields_by_name['name']._options = None
  _CREATEINVENTORYOBJECTREQUEST_SUBCOLUMN.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEINVENTORYOBJECTREQUEST_SUBCOLUMN.fields_by_name['sub_type']._options = None
  _CREATEINVENTORYOBJECTREQUEST_SUBCOLUMN.fields_by_name['sub_type']._serialized_options = b'\372B\020r\016R\006hstoreR\004json'
  _CREATEINVENTORYOBJECTREQUEST.fields_by_name['datastore_id']._options = None
  _CREATEINVENTORYOBJECTREQUEST.fields_by_name['datastore_id']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEINVENTORYOBJECTREQUEST.fields_by_name['object_type']._options = None
  _CREATEINVENTORYOBJECTREQUEST.fields_by_name['object_type']._serialized_options = b'\372B)r\'R\002dbR\006schemaR\005tableR\006columnR\nsub-column'
  _DELETEINVENTORYOBJECTREQUEST.fields_by_name['datastore_id']._options = None
  _DELETEINVENTORYOBJECTREQUEST.fields_by_name['datastore_id']._serialized_options = b'\372B\004r\002\020\001'
  _DELETEINVENTORYOBJECTREQUEST.fields_by_name['path']._options = None
  _DELETEINVENTORYOBJECTREQUEST.fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _TAG.fields_by_name['name']._options = None
  _TAG.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEINVENTORYTAGREQUEST.fields_by_name['name']._options = None
  _CREATEINVENTORYTAGREQUEST.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _UPDATEINVENTORYOBJECTTAGSREQUEST.fields_by_name['datastore_id']._options = None
  _UPDATEINVENTORYOBJECTTAGSREQUEST.fields_by_name['datastore_id']._serialized_options = b'\372B\004r\002\020\001'
  _UPDATEINVENTORYOBJECTTAGSREQUEST.fields_by_name['path']._options = None
  _UPDATEINVENTORYOBJECTTAGSREQUEST.fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _DELETEINVENTORYTAGREQUEST.fields_by_name['id']._options = None
  _DELETEINVENTORYTAGREQUEST.fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _EMPTY._serialized_start=63
  _EMPTY._serialized_end=70
  _CHUNK._serialized_start=72
  _CHUNK._serialized_end=94
  _GETINVENTORYHIERARCHICALREQUEST._serialized_start=96
  _GETINVENTORYHIERARCHICALREQUEST._serialized_end=129
  _GETINVENTORYHIERARCHICALRESPONSE._serialized_start=132
  _GETINVENTORYHIERARCHICALRESPONSE._serialized_end=1021
  _GETINVENTORYHIERARCHICALRESPONSE_DATASTORE._serialized_start=246
  _GETINVENTORYHIERARCHICALRESPONSE_DATASTORE._serialized_end=348
  _GETINVENTORYHIERARCHICALRESPONSE_DB._serialized_start=351
  _GETINVENTORYHIERARCHICALRESPONSE_DB._serialized_end=549
  _GETINVENTORYHIERARCHICALRESPONSE_SCHEMA._serialized_start=551
  _GETINVENTORYHIERARCHICALRESPONSE_SCHEMA._serialized_end=675
  _GETINVENTORYHIERARCHICALRESPONSE_TABLE._serialized_start=678
  _GETINVENTORYHIERARCHICALRESPONSE_TABLE._serialized_end=824
  _GETINVENTORYHIERARCHICALRESPONSE_COLUMN._serialized_start=827
  _GETINVENTORYHIERARCHICALRESPONSE_COLUMN._serialized_end=959
  _GETINVENTORYHIERARCHICALRESPONSE_SUBCOLUMN._serialized_start=961
  _GETINVENTORYHIERARCHICALRESPONSE_SUBCOLUMN._serialized_end=1021
  _GETINVENTORYFLATREQUEST._serialized_start=1023
  _GETINVENTORYFLATREQUEST._serialized_end=1048
  _GETINVENTORYFLATRESPONSE._serialized_start=1051
  _GETINVENTORYFLATRESPONSE._serialized_end=1458
  _GETINVENTORYFLATRESPONSE_COLUMN._serialized_start=1147
  _GETINVENTORYFLATRESPONSE_COLUMN._serialized_end=1458
  _UPDATECOLUMNLOCKSTATUSREQUEST._serialized_start=1460
  _UPDATECOLUMNLOCKSTATUSREQUEST._serialized_end=1564
  _UPDATECOLUMNLOCKSTATUSRESPONSE._serialized_start=1566
  _UPDATECOLUMNLOCKSTATUSRESPONSE._serialized_end=1598
  _UPDATECOLUMNDATALABELREQUEST._serialized_start=1600
  _UPDATECOLUMNDATALABELREQUEST._serialized_end=1704
  _UPDATECOLUMNDATALABELRESPONSE._serialized_start=1706
  _UPDATECOLUMNDATALABELRESPONSE._serialized_end=1737
  _CREATEINVENTORYOBJECTREQUEST._serialized_start=1740
  _CREATEINVENTORYOBJECTREQUEST._serialized_end=2550
  _CREATEINVENTORYOBJECTREQUEST_DB._serialized_start=2207
  _CREATEINVENTORYOBJECTREQUEST_DB._serialized_end=2257
  _CREATEINVENTORYOBJECTREQUEST_SCHEMA._serialized_start=2259
  _CREATEINVENTORYOBJECTREQUEST_SCHEMA._serialized_end=2313
  _CREATEINVENTORYOBJECTREQUEST_TABLE._serialized_start=2315
  _CREATEINVENTORYOBJECTREQUEST_TABLE._serialized_end=2368
  _CREATEINVENTORYOBJECTREQUEST_COLUMN._serialized_start=2370
  _CREATEINVENTORYOBJECTREQUEST_COLUMN._serialized_end=2452
  _CREATEINVENTORYOBJECTREQUEST_SUBCOLUMN._serialized_start=2454
  _CREATEINVENTORYOBJECTREQUEST_SUBCOLUMN._serialized_end=2550
  _CREATEINVENTORYOBJECTRESPONSE._serialized_start=2552
  _CREATEINVENTORYOBJECTRESPONSE._serialized_end=2583
  _DELETEINVENTORYOBJECTREQUEST._serialized_start=2585
  _DELETEINVENTORYOBJECTREQUEST._serialized_end=2669
  _DELETEINVENTORYOBJECTRESPONSE._serialized_start=2671
  _DELETEINVENTORYOBJECTRESPONSE._serialized_end=2702
  _TAG._serialized_start=2704
  _TAG._serialized_end=2764
  _CREATEINVENTORYTAGREQUEST._serialized_start=2766
  _CREATEINVENTORYTAGREQUEST._serialized_end=2816
  _CREATEINVENTORYTAGRESPONSE._serialized_start=2818
  _CREATEINVENTORYTAGRESPONSE._serialized_end=2879
  _GETINVENTORYTAGSREQUEST._serialized_start=2881
  _GETINVENTORYTAGSREQUEST._serialized_end=2906
  _GETINVENTORYTAGSRESPONSE._serialized_start=2908
  _GETINVENTORYTAGSRESPONSE._serialized_end=2968
  _UPDATEINVENTORYOBJECTTAGSREQUEST._serialized_start=2970
  _UPDATEINVENTORYOBJECTTAGSREQUEST._serialized_end=3072
  _UPDATEINVENTORYOBJECTTAGSRESPONSE._serialized_start=3075
  _UPDATEINVENTORYOBJECTTAGSRESPONSE._serialized_end=3503
  _UPDATEINVENTORYOBJECTTAGSRESPONSE_INVENTORYOBJECT._serialized_start=3195
  _UPDATEINVENTORYOBJECTTAGSRESPONSE_INVENTORYOBJECT._serialized_end=3503
  _DELETEINVENTORYTAGREQUEST._serialized_start=3505
  _DELETEINVENTORYTAGREQUEST._serialized_end=3553
  _DELETEINVENTORYTAGRESPONSE._serialized_start=3555
  _DELETEINVENTORYTAGRESPONSE._serialized_end=3617
  _ADMINAPISERVICE._serialized_start=3620
  _ADMINAPISERVICE._serialized_end=4794
# @@protoc_insertion_point(module_scope)



from __future__ import print_function


import grpc

# import aa_service_pb2_grpc,interceptor
from . import aa_service_pb2_grpc,interceptor


SERVER_URL = "adminv2.api.formalcloud.net"
# SERVER_URL = "localhost:8080"

class Client(object):
    """Formal Admin API Client"""

    def __init__(self, client_id, api_key):
        """Constructor.

        Args:
            client_id: Formal Client ID
            api_key: Formal API Key
        """
        
        channel = grpc.secure_channel(SERVER_URL, grpc.ssl_channel_credentials())
        interceptors = [interceptor.MetadataClientInterceptor(client_id, api_key)]
        channel = grpc.intercept_channel(channel, *interceptors)
        stub = aa_service_pb2_grpc.AdminApiServiceStub(channel)
        self.Service = stub